@@ -13,12 +13,15 @@
 #' @param by Character vector, names of columns in \code{x} and \code{y} to use to join data. See [dplyr::full_join()].
 #' @param compare.order Logical, whether or not the order of the rows should be compared. If \code{TRUE}, then \code{x} and \code{y}
 #' will also be joined by row number. See \code{\link{full_join}}.
+#' @param threshold Numeric, threshold difference for comparison of numeric values. Set to 0 to only accept identical values.
 #' @param ... Other arguments passed on to functions to read the files to compare (e.g. \code{\link{ReadGeoData}}, \code{\link{ReadPar}}, etc.).
 #'
 #' @details
 #' \code{CompareFiles} compares two HYPE model files and identifies any differences in values. The function reads two model files, compares
 #' the values in columns with corresponding names, and returns a data frame consisting of rows/columns with any differences. Values that are
-#' the same in both files are set to \code{NA}. The function is primarily intended as a check to ensure that no unintended changes were made when writing
+#' the same in both files are set to \code{NA}. If numeric values in two columns aren't exactly the same, then the difference between the values will be taken
+#' and compare to \code{theshold}. If the difference is <= \code{theshold}, then the values will be considered the equal and set to \code{NA}.
+#' The function is primarily intended as a check to ensure that no unintended changes were made when writing
 #' model files using the various HYPEtools write functions. However, it can also be used to e.g. compare files between different model versions.
 #'
 #' @return
@@ -39,7 +42,7 @@
 #' @importFrom rlang .data
 #' @export
 
-CompareFiles <- function(x, y, type, by = NULL, compare.order = TRUE, ...) {
+CompareFiles <- function(x, y, type, by = NULL, compare.order = TRUE, threshold = 1E-10, ...) {
 
   # Create function to read files
   ReadFile <- function(file, type, ...) {
@@ -191,6 +194,20 @@ CompareFiles <- function(x, y, type, by = NULL, compare.order = TRUE, ...) {
     # Set values to NA if they are the same
     compare[which(same == TRUE), paste0(col, ".x")] <- NA
     compare[which(same == TRUE), paste0(col, ".y")] <- NA
+
+    # If columns are numeric type, then check if values that aren't the same are within specified threshold of eachother
+    if(inherits(compare[[paste0(col, ".x")]], "numeric") & inherits(compare[[paste0(col, ".y")]], "numeric")){
+      
+      # Check if values are within threshold of eachother
+      close <- abs(compare[paste0(col, ".x")] - compare[paste0(col, ".y")]) <= threshold
+      
+      # Set values to TRUE if they were identical above
+      close[which(same == TRUE)] <- TRUE
+
+      # Set values to NA if they are within specified threshold of eachother
+      compare[which(close == TRUE), paste0(col, ".x")] <- NA
+      compare[which(close == TRUE), paste0(col, ".y")] <- NA
+    }
   }
 
   # Remove columns and rows that are all NA
